#!C:\Miniconda3\conda-bld\gdal-split_1534094378827\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==2.3.1','gdal_retile.py'
__requires__ = 'GDAL==2.3.1'
__import__('pkg_resources').run_script('GDAL==2.3.1', 'gdal_retile.py')
